Class: Google::Cloud::DiscoveryEngine::V1::Answer::Reference::UnstructuredDocumentInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1/answer.rb

Overview

Unstructured document information.

Defined Under Namespace

Classes: ChunkContent

Instance Attribute Summary collapse

Instance Attribute Details

#chunk_contents::Array<::Google::Cloud::DiscoveryEngine::V1::Answer::Reference::UnstructuredDocumentInfo::ChunkContent>



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'proto_docs/google/cloud/discoveryengine/v1/answer.rb', line 168

class UnstructuredDocumentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Chunk content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] page_identifier
  #   @return [::String]
  #     Page identifier.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     The relevance of the chunk for a given query. Values range from 0.0
  #     (completely irrelevant) to 1.0 (completely relevant).
  #     This value is for informational purpose only. It may change for
  #     the same query and chunk at any time due to a model retraining or
  #     change in implementation.
  class ChunkContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#document::String



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'proto_docs/google/cloud/discoveryengine/v1/answer.rb', line 168

class UnstructuredDocumentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Chunk content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] page_identifier
  #   @return [::String]
  #     Page identifier.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     The relevance of the chunk for a given query. Values range from 0.0
  #     (completely irrelevant) to 1.0 (completely relevant).
  #     This value is for informational purpose only. It may change for
  #     the same query and chunk at any time due to a model retraining or
  #     change in implementation.
  class ChunkContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#struct_data::Google::Protobuf::Struct



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'proto_docs/google/cloud/discoveryengine/v1/answer.rb', line 168

class UnstructuredDocumentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Chunk content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] page_identifier
  #   @return [::String]
  #     Page identifier.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     The relevance of the chunk for a given query. Values range from 0.0
  #     (completely irrelevant) to 1.0 (completely relevant).
  #     This value is for informational purpose only. It may change for
  #     the same query and chunk at any time due to a model retraining or
  #     change in implementation.
  class ChunkContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#title::String



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'proto_docs/google/cloud/discoveryengine/v1/answer.rb', line 168

class UnstructuredDocumentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Chunk content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] page_identifier
  #   @return [::String]
  #     Page identifier.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     The relevance of the chunk for a given query. Values range from 0.0
  #     (completely irrelevant) to 1.0 (completely relevant).
  #     This value is for informational purpose only. It may change for
  #     the same query and chunk at any time due to a model retraining or
  #     change in implementation.
  class ChunkContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uri::String



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'proto_docs/google/cloud/discoveryengine/v1/answer.rb', line 168

class UnstructuredDocumentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Chunk content.
  # @!attribute [rw] content
  #   @return [::String]
  #     Chunk textual content.
  # @!attribute [rw] page_identifier
  #   @return [::String]
  #     Page identifier.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     The relevance of the chunk for a given query. Values range from 0.0
  #     (completely irrelevant) to 1.0 (completely relevant).
  #     This value is for informational purpose only. It may change for
  #     the same query and chunk at any time due to a model retraining or
  #     change in implementation.
  class ChunkContent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end