Class: Google::Cloud::DiscoveryEngine::V1::CheckGroundingSpec
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1::CheckGroundingSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1/grounded_generation_service.rb
Overview
Specification for the grounding check.
Instance Attribute Summary collapse
-
#citation_threshold ⇒ ::Float
The threshold (in [0,1]) used for determining whether a fact must be cited for a claim in the answer candidate.
-
#enable_claim_level_score ⇒ ::Boolean
The control flag that enables claim-level grounding score in the response.
Instance Attribute Details
#citation_threshold ⇒ ::Float
Returns The threshold (in [0,1]) used for determining whether a fact must be cited for a claim in the answer candidate. Choosing a higher threshold will lead to fewer but very strong citations, while choosing a lower threshold may lead to more but somewhat weaker citations. If unset, the threshold will default to 0.6.
482 483 484 485 |
# File 'proto_docs/google/cloud/discoveryengine/v1/grounded_generation_service.rb', line 482 class CheckGroundingSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enable_claim_level_score ⇒ ::Boolean
Returns The control flag that enables claim-level grounding score in the response.
482 483 484 485 |
# File 'proto_docs/google/cloud/discoveryengine/v1/grounded_generation_service.rb', line 482 class CheckGroundingSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |