Class: Google::Cloud::DiscoveryEngine::V1::ImportUserEventsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1/import_config.rb

Overview

Request message for the ImportUserEvents request.

Defined Under Namespace

Classes: InlineSource

Instance Attribute Summary collapse

Instance Attribute Details

#bigquery_source::Google::Cloud::DiscoveryEngine::V1::BigQuerySource



456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'proto_docs/google/cloud/discoveryengine/v1/import_config.rb', line 456

class ImportUserEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The inline source for the input config for ImportUserEvents method.
  # @!attribute [rw] user_events
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1::UserEvent>]
  #     Required. A list of user events to import. Recommended max of 10k items.
  class InlineSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#error_config::Google::Cloud::DiscoveryEngine::V1::ImportErrorConfig



456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'proto_docs/google/cloud/discoveryengine/v1/import_config.rb', line 456

class ImportUserEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The inline source for the input config for ImportUserEvents method.
  # @!attribute [rw] user_events
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1::UserEvent>]
  #     Required. A list of user events to import. Recommended max of 10k items.
  class InlineSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#gcs_source::Google::Cloud::DiscoveryEngine::V1::GcsSource



456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'proto_docs/google/cloud/discoveryengine/v1/import_config.rb', line 456

class ImportUserEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The inline source for the input config for ImportUserEvents method.
  # @!attribute [rw] user_events
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1::UserEvent>]
  #     Required. A list of user events to import. Recommended max of 10k items.
  class InlineSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#inline_source::Google::Cloud::DiscoveryEngine::V1::ImportUserEventsRequest::InlineSource



456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'proto_docs/google/cloud/discoveryengine/v1/import_config.rb', line 456

class ImportUserEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The inline source for the input config for ImportUserEvents method.
  # @!attribute [rw] user_events
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1::UserEvent>]
  #     Required. A list of user events to import. Recommended max of 10k items.
  class InlineSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#parent::String



456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'proto_docs/google/cloud/discoveryengine/v1/import_config.rb', line 456

class ImportUserEventsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The inline source for the input config for ImportUserEvents method.
  # @!attribute [rw] user_events
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1::UserEvent>]
  #     Required. A list of user events to import. Recommended max of 10k items.
  class InlineSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end