Class: Google::Cloud::DiscoveryEngine::V1::NaturalLanguageQueryUnderstandingConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1/data_store.rb

Overview

Configuration for Natural Language Query Understanding.

Defined Under Namespace

Modules: Mode

Instance Attribute Summary collapse

Instance Attribute Details

#mode::Google::Cloud::DiscoveryEngine::V1::NaturalLanguageQueryUnderstandingConfig::Mode

Returns Mode of Natural Language Query Understanding. If this field is unset, the behavior defaults to NaturalLanguageQueryUnderstandingConfig.Mode.DISABLED.

Returns:



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'proto_docs/google/cloud/discoveryengine/v1/data_store.rb', line 213

class NaturalLanguageQueryUnderstandingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode of Natural Language Query Understanding. When the
  # NaturalLanguageQueryUnderstandingConfig.Mode is ENABLED, the natural
  # language understanding capabilities will be enabled for a search request if
  # the NaturalLanguageQueryUnderstandingSpec.FilterExtractionCondition in the
  # SearchRequest is ENABLED.
  module Mode
    # Default value.
    MODE_UNSPECIFIED = 0

    # Natural Language Query Understanding is disabled.
    DISABLED = 1

    # Natural Language Query Understanding is enabled.
    ENABLED = 2
  end
end