Class: Google::Cloud::DiscoveryEngine::V1::SearchRequest::BoostSpec::ConditionBoostSpec::BoostControlSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1/search_service.rb

Overview

Specification for custom ranking based on customer specified attribute value. It provides more controls for customized ranking than the simple (condition, boost) combination above.

Defined Under Namespace

Modules: AttributeType, InterpolationType Classes: ControlPoint

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_type::Google::Cloud::DiscoveryEngine::V1::SearchRequest::BoostSpec::ConditionBoostSpec::BoostControlSpec::AttributeType

Returns The attribute type to be used to determine the boost amount. The attribute value can be derived from the field value of the specified field_name. In the case of numerical it is straightforward i.e. attribute_value = numerical_field_value. In the case of freshness however, attribute_value = (time.now() - datetime_field_value).

Returns:



675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 675

class BoostControlSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The control points used to define the curve. The curve defined
  # through these control points can only be monotonically increasing
  # or decreasing(constant values are acceptable).
  # @!attribute [rw] attribute_value
  #   @return [::String]
  #     Can be one of:
  #     1. The numerical field value.
  #     2. The duration spec for freshness:
  #     The value must be formatted as an XSD `dayTimeDuration` value (a
  #     restricted subset of an ISO 8601 duration value). The pattern for
  #     this is: `[nD][T[nH][nM][nS]]`.
  # @!attribute [rw] boost_amount
  #   @return [::Float]
  #     The value between -1 to 1 by which to boost the score if the
  #     attribute_value evaluates to the value specified above.
  class ControlPoint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The attribute(or function) for which the custom ranking is to be
  # applied.
  module AttributeType
    # Unspecified AttributeType.
    ATTRIBUTE_TYPE_UNSPECIFIED = 0

    # The value of the numerical field will be used to dynamically update
    # the boost amount. In this case, the attribute_value (the x value)
    # of the control point will be the actual value of the numerical
    # field for which the boost_amount is specified.
    NUMERICAL = 1

    # For the freshness use case the attribute value will be the duration
    # between the current time and the date in the datetime field
    # specified. The value must be formatted as an XSD `dayTimeDuration`
    # value (a restricted subset of an ISO 8601 duration value). The
    # pattern for this is: `[nD][T[nH][nM][nS]]`.
    # For example, `5D`, `3DT12H30M`, `T24H`.
    FRESHNESS = 2
  end

  # The interpolation type to be applied. Default will be linear
  # (Piecewise Linear).
  module InterpolationType
    # Interpolation type is unspecified. In this case, it defaults to
    # Linear.
    INTERPOLATION_TYPE_UNSPECIFIED = 0

    # Piecewise linear interpolation will be applied.
    LINEAR = 1
  end
end

#control_points::Array<::Google::Cloud::DiscoveryEngine::V1::SearchRequest::BoostSpec::ConditionBoostSpec::BoostControlSpec::ControlPoint>

Returns The control points used to define the curve. The monotonic function (defined through the interpolation_type above) passes through the control points listed here.

Returns:



675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 675

class BoostControlSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The control points used to define the curve. The curve defined
  # through these control points can only be monotonically increasing
  # or decreasing(constant values are acceptable).
  # @!attribute [rw] attribute_value
  #   @return [::String]
  #     Can be one of:
  #     1. The numerical field value.
  #     2. The duration spec for freshness:
  #     The value must be formatted as an XSD `dayTimeDuration` value (a
  #     restricted subset of an ISO 8601 duration value). The pattern for
  #     this is: `[nD][T[nH][nM][nS]]`.
  # @!attribute [rw] boost_amount
  #   @return [::Float]
  #     The value between -1 to 1 by which to boost the score if the
  #     attribute_value evaluates to the value specified above.
  class ControlPoint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The attribute(or function) for which the custom ranking is to be
  # applied.
  module AttributeType
    # Unspecified AttributeType.
    ATTRIBUTE_TYPE_UNSPECIFIED = 0

    # The value of the numerical field will be used to dynamically update
    # the boost amount. In this case, the attribute_value (the x value)
    # of the control point will be the actual value of the numerical
    # field for which the boost_amount is specified.
    NUMERICAL = 1

    # For the freshness use case the attribute value will be the duration
    # between the current time and the date in the datetime field
    # specified. The value must be formatted as an XSD `dayTimeDuration`
    # value (a restricted subset of an ISO 8601 duration value). The
    # pattern for this is: `[nD][T[nH][nM][nS]]`.
    # For example, `5D`, `3DT12H30M`, `T24H`.
    FRESHNESS = 2
  end

  # The interpolation type to be applied. Default will be linear
  # (Piecewise Linear).
  module InterpolationType
    # Interpolation type is unspecified. In this case, it defaults to
    # Linear.
    INTERPOLATION_TYPE_UNSPECIFIED = 0

    # Piecewise linear interpolation will be applied.
    LINEAR = 1
  end
end

#field_name::String

Returns The name of the field whose value will be used to determine the boost amount.

Returns:

  • (::String)

    The name of the field whose value will be used to determine the boost amount.



675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 675

class BoostControlSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The control points used to define the curve. The curve defined
  # through these control points can only be monotonically increasing
  # or decreasing(constant values are acceptable).
  # @!attribute [rw] attribute_value
  #   @return [::String]
  #     Can be one of:
  #     1. The numerical field value.
  #     2. The duration spec for freshness:
  #     The value must be formatted as an XSD `dayTimeDuration` value (a
  #     restricted subset of an ISO 8601 duration value). The pattern for
  #     this is: `[nD][T[nH][nM][nS]]`.
  # @!attribute [rw] boost_amount
  #   @return [::Float]
  #     The value between -1 to 1 by which to boost the score if the
  #     attribute_value evaluates to the value specified above.
  class ControlPoint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The attribute(or function) for which the custom ranking is to be
  # applied.
  module AttributeType
    # Unspecified AttributeType.
    ATTRIBUTE_TYPE_UNSPECIFIED = 0

    # The value of the numerical field will be used to dynamically update
    # the boost amount. In this case, the attribute_value (the x value)
    # of the control point will be the actual value of the numerical
    # field for which the boost_amount is specified.
    NUMERICAL = 1

    # For the freshness use case the attribute value will be the duration
    # between the current time and the date in the datetime field
    # specified. The value must be formatted as an XSD `dayTimeDuration`
    # value (a restricted subset of an ISO 8601 duration value). The
    # pattern for this is: `[nD][T[nH][nM][nS]]`.
    # For example, `5D`, `3DT12H30M`, `T24H`.
    FRESHNESS = 2
  end

  # The interpolation type to be applied. Default will be linear
  # (Piecewise Linear).
  module InterpolationType
    # Interpolation type is unspecified. In this case, it defaults to
    # Linear.
    INTERPOLATION_TYPE_UNSPECIFIED = 0

    # Piecewise linear interpolation will be applied.
    LINEAR = 1
  end
end

#interpolation_type::Google::Cloud::DiscoveryEngine::V1::SearchRequest::BoostSpec::ConditionBoostSpec::BoostControlSpec::InterpolationType

Returns The interpolation type to be applied to connect the control points listed below.

Returns:



675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 675

class BoostControlSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The control points used to define the curve. The curve defined
  # through these control points can only be monotonically increasing
  # or decreasing(constant values are acceptable).
  # @!attribute [rw] attribute_value
  #   @return [::String]
  #     Can be one of:
  #     1. The numerical field value.
  #     2. The duration spec for freshness:
  #     The value must be formatted as an XSD `dayTimeDuration` value (a
  #     restricted subset of an ISO 8601 duration value). The pattern for
  #     this is: `[nD][T[nH][nM][nS]]`.
  # @!attribute [rw] boost_amount
  #   @return [::Float]
  #     The value between -1 to 1 by which to boost the score if the
  #     attribute_value evaluates to the value specified above.
  class ControlPoint
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The attribute(or function) for which the custom ranking is to be
  # applied.
  module AttributeType
    # Unspecified AttributeType.
    ATTRIBUTE_TYPE_UNSPECIFIED = 0

    # The value of the numerical field will be used to dynamically update
    # the boost amount. In this case, the attribute_value (the x value)
    # of the control point will be the actual value of the numerical
    # field for which the boost_amount is specified.
    NUMERICAL = 1

    # For the freshness use case the attribute value will be the duration
    # between the current time and the date in the datetime field
    # specified. The value must be formatted as an XSD `dayTimeDuration`
    # value (a restricted subset of an ISO 8601 duration value). The
    # pattern for this is: `[nD][T[nH][nM][nS]]`.
    # For example, `5D`, `3DT12H30M`, `T24H`.
    FRESHNESS = 2
  end

  # The interpolation type to be applied. Default will be linear
  # (Piecewise Linear).
  module InterpolationType
    # Interpolation type is unspecified. In this case, it defaults to
    # Linear.
    INTERPOLATION_TYPE_UNSPECIFIED = 0

    # Piecewise linear interpolation will be applied.
    LINEAR = 1
  end
end