Module: Google::Cloud::DiscoveryEngine::V1::SearchRequest::CrowdingSpec::Mode

Defined in:
proto_docs/google/cloud/discoveryengine/v1/search_service.rb

Overview

Enum describing the mode to use for documents that are crowded away. They can be dropped or demoted to the later pages.

Constant Summary collapse

MODE_UNSPECIFIED =

Unspecified crowding mode. In this case, server behavior defaults to Mode.DROP_CROWDED_RESULTS.

0
DROP_CROWDED_RESULTS =

Drop crowded results.

1
DEMOTE_CROWDED_RESULTS_TO_END =

Demote crowded results to the later pages.

2