Class: Google::Cloud::DiscoveryEngine::V1::SearchRequest::DataStoreSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1/search_service.rb

Overview

A struct to define data stores to filter on in a search call and configurations for those data stores. Otherwise, an INVALID_ARGUMENT error is returned.

Instance Attribute Summary collapse

Instance Attribute Details

#boost_spec::Google::Cloud::DiscoveryEngine::V1::SearchRequest::BoostSpec

Returns Optional. Boost specification to boost certain documents. For more information on boosting, see Boosting.

Returns:



455
456
457
458
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 455

class DataStoreSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#custom_search_operators::String

Returns Optional. Custom search operators which if specified will be used to filter results from workspace data stores. For more information on custom search operators, see SearchOperators.

Returns:

  • (::String)

    Optional. Custom search operators which if specified will be used to filter results from workspace data stores. For more information on custom search operators, see SearchOperators.



455
456
457
458
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 455

class DataStoreSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_store::String

Returns Required. Full resource name of DataStore, such as projects/{project}/locations/{location}/collections/{collection_id}/dataStores/{data_store_id}. The path must include the project number, project id is not supported for this field.

Returns:

  • (::String)

    Required. Full resource name of DataStore, such as projects/{project}/locations/{location}/collections/{collection_id}/dataStores/{data_store_id}. The path must include the project number, project id is not supported for this field.



455
456
457
458
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 455

class DataStoreSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#filter::String

Returns Optional. Filter specification to filter documents in the data store specified by data_store field. For more information on filtering, see Filtering.

Returns:

  • (::String)

    Optional. Filter specification to filter documents in the data store specified by data_store field. For more information on filtering, see Filtering



455
456
457
458
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 455

class DataStoreSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end