Class: Google::Cloud::DiscoveryEngine::V1::SearchRequest::DisplaySpec
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1::SearchRequest::DisplaySpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1/search_service.rb
Overview
Specifies features for display, like match highlighting.
Defined Under Namespace
Modules: MatchHighlightingCondition
Instance Attribute Summary collapse
-
#match_highlighting_condition ⇒ ::Google::Cloud::DiscoveryEngine::V1::SearchRequest::DisplaySpec::MatchHighlightingCondition
The condition under which match highlighting should occur.
Instance Attribute Details
#match_highlighting_condition ⇒ ::Google::Cloud::DiscoveryEngine::V1::SearchRequest::DisplaySpec::MatchHighlightingCondition
Returns The condition under which match highlighting should occur.
1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 |
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1184 class DisplaySpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum describing under which condition match highlighting should occur. module MatchHighlightingCondition # Server behavior is the same as `MATCH_HIGHLIGHTING_DISABLED`. MATCH_HIGHLIGHTING_CONDITION_UNSPECIFIED = 0 # Disables match highlighting on all documents. MATCH_HIGHLIGHTING_DISABLED = 1 # Enables match highlighting on all documents. MATCH_HIGHLIGHTING_ENABLED = 2 end end |