Class: Google::Cloud::DiscoveryEngine::V1::SearchRequest::NaturalLanguageQueryUnderstandingSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1/search_service.rb

Overview

Specification to enable natural language understanding capabilities for search requests.

Defined Under Namespace

Modules: ExtractedFilterBehavior, FilterExtractionCondition

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_field_names::Array<::String>



1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1108

class NaturalLanguageQueryUnderstandingSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum describing under which condition filter extraction should occur.
  module FilterExtractionCondition
    # Server behavior defaults to `DISABLED`.
    CONDITION_UNSPECIFIED = 0

    # Disables NL filter extraction.
    DISABLED = 1

    # Enables NL filter extraction.
    ENABLED = 2
  end

  # Enum describing how extracted filters are applied to the search.
  module ExtractedFilterBehavior
    # `EXTRACTED_FILTER_BEHAVIOR_UNSPECIFIED` will use the default behavior
    # for extracted filters. For single datastore search, the default is to
    # apply as hard filters. For multi-datastore search, the default is to
    # apply as soft boosts.
    EXTRACTED_FILTER_BEHAVIOR_UNSPECIFIED = 0

    # Applies all extracted filters as hard filters on the results. Results
    # that do not pass the extracted filters will not be returned in the
    # result set.
    HARD_FILTER = 1

    # Applies all extracted filters as soft boosts. Results that pass the
    # filters will be boosted up to higher ranks in the result set.
    SOFT_BOOST = 2
  end
end

#extracted_filter_behavior::Google::Cloud::DiscoveryEngine::V1::SearchRequest::NaturalLanguageQueryUnderstandingSpec::ExtractedFilterBehavior



1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1108

class NaturalLanguageQueryUnderstandingSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum describing under which condition filter extraction should occur.
  module FilterExtractionCondition
    # Server behavior defaults to `DISABLED`.
    CONDITION_UNSPECIFIED = 0

    # Disables NL filter extraction.
    DISABLED = 1

    # Enables NL filter extraction.
    ENABLED = 2
  end

  # Enum describing how extracted filters are applied to the search.
  module ExtractedFilterBehavior
    # `EXTRACTED_FILTER_BEHAVIOR_UNSPECIFIED` will use the default behavior
    # for extracted filters. For single datastore search, the default is to
    # apply as hard filters. For multi-datastore search, the default is to
    # apply as soft boosts.
    EXTRACTED_FILTER_BEHAVIOR_UNSPECIFIED = 0

    # Applies all extracted filters as hard filters on the results. Results
    # that do not pass the extracted filters will not be returned in the
    # result set.
    HARD_FILTER = 1

    # Applies all extracted filters as soft boosts. Results that pass the
    # filters will be boosted up to higher ranks in the result set.
    SOFT_BOOST = 2
  end
end

#filter_extraction_condition::Google::Cloud::DiscoveryEngine::V1::SearchRequest::NaturalLanguageQueryUnderstandingSpec::FilterExtractionCondition



1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1108

class NaturalLanguageQueryUnderstandingSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum describing under which condition filter extraction should occur.
  module FilterExtractionCondition
    # Server behavior defaults to `DISABLED`.
    CONDITION_UNSPECIFIED = 0

    # Disables NL filter extraction.
    DISABLED = 1

    # Enables NL filter extraction.
    ENABLED = 2
  end

  # Enum describing how extracted filters are applied to the search.
  module ExtractedFilterBehavior
    # `EXTRACTED_FILTER_BEHAVIOR_UNSPECIFIED` will use the default behavior
    # for extracted filters. For single datastore search, the default is to
    # apply as hard filters. For multi-datastore search, the default is to
    # apply as soft boosts.
    EXTRACTED_FILTER_BEHAVIOR_UNSPECIFIED = 0

    # Applies all extracted filters as hard filters on the results. Results
    # that do not pass the extracted filters will not be returned in the
    # result set.
    HARD_FILTER = 1

    # Applies all extracted filters as soft boosts. Results that pass the
    # filters will be boosted up to higher ranks in the result set.
    SOFT_BOOST = 2
  end
end

#geo_search_query_detection_field_names::Array<::String>



1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1108

class NaturalLanguageQueryUnderstandingSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum describing under which condition filter extraction should occur.
  module FilterExtractionCondition
    # Server behavior defaults to `DISABLED`.
    CONDITION_UNSPECIFIED = 0

    # Disables NL filter extraction.
    DISABLED = 1

    # Enables NL filter extraction.
    ENABLED = 2
  end

  # Enum describing how extracted filters are applied to the search.
  module ExtractedFilterBehavior
    # `EXTRACTED_FILTER_BEHAVIOR_UNSPECIFIED` will use the default behavior
    # for extracted filters. For single datastore search, the default is to
    # apply as hard filters. For multi-datastore search, the default is to
    # apply as soft boosts.
    EXTRACTED_FILTER_BEHAVIOR_UNSPECIFIED = 0

    # Applies all extracted filters as hard filters on the results. Results
    # that do not pass the extracted filters will not be returned in the
    # result set.
    HARD_FILTER = 1

    # Applies all extracted filters as soft boosts. Results that pass the
    # filters will be boosted up to higher ranks in the result set.
    SOFT_BOOST = 2
  end
end