Class: Google::Cloud::DiscoveryEngine::V1::SearchRequest::QueryExpansionSpec
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1::SearchRequest::QueryExpansionSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1/search_service.rb
Overview
Specification to determine under which conditions query expansion should occur.
Defined Under Namespace
Modules: Condition
Instance Attribute Summary collapse
-
#condition ⇒ ::Google::Cloud::DiscoveryEngine::V1::SearchRequest::QueryExpansionSpec::Condition
The condition under which query expansion should occur.
-
#pin_unexpanded_results ⇒ ::Boolean
Whether to pin unexpanded results.
Instance Attribute Details
#condition ⇒ ::Google::Cloud::DiscoveryEngine::V1::SearchRequest::QueryExpansionSpec::Condition
745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 |
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 745 class QueryExpansionSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum describing under which condition query expansion should occur. module Condition # Unspecified query expansion condition. In this case, server behavior # defaults to # {::Google::Cloud::DiscoveryEngine::V1::SearchRequest::QueryExpansionSpec::Condition::DISABLED Condition.DISABLED}. CONDITION_UNSPECIFIED = 0 # Disabled query expansion. Only the exact search query is used, even if # {::Google::Cloud::DiscoveryEngine::V1::SearchResponse#total_size SearchResponse.total_size} # is zero. DISABLED = 1 # Automatic query expansion built by the Search API. AUTO = 2 end end |
#pin_unexpanded_results ⇒ ::Boolean
745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 |
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 745 class QueryExpansionSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum describing under which condition query expansion should occur. module Condition # Unspecified query expansion condition. In this case, server behavior # defaults to # {::Google::Cloud::DiscoveryEngine::V1::SearchRequest::QueryExpansionSpec::Condition::DISABLED Condition.DISABLED}. CONDITION_UNSPECIFIED = 0 # Disabled query expansion. Only the exact search query is used, even if # {::Google::Cloud::DiscoveryEngine::V1::SearchResponse#total_size SearchResponse.total_size} # is zero. DISABLED = 1 # Automatic query expansion built by the Search API. AUTO = 2 end end |