Class: Google::Cloud::DiscoveryEngine::V1::SearchRequest::SpellCorrectionSpec
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1::SearchRequest::SpellCorrectionSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1/search_service.rb
Overview
The specification for query spell correction.
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#mode ⇒ ::Google::Cloud::DiscoveryEngine::V1::SearchRequest::SpellCorrectionSpec::Mode
The mode under which spell correction replaces the original search query.
Instance Attribute Details
#mode ⇒ ::Google::Cloud::DiscoveryEngine::V1::SearchRequest::SpellCorrectionSpec::Mode
Returns The mode under which spell correction replaces the original search query. Defaults to Mode.AUTO.
781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 781 class SpellCorrectionSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum describing under which mode spell correction should occur. module Mode # Unspecified spell correction mode. In this case, server behavior # defaults to # {::Google::Cloud::DiscoveryEngine::V1::SearchRequest::SpellCorrectionSpec::Mode::AUTO Mode.AUTO}. MODE_UNSPECIFIED = 0 # Search API tries to find a spelling suggestion. If a suggestion is # found, it is put in the # {::Google::Cloud::DiscoveryEngine::V1::SearchResponse#corrected_query SearchResponse.corrected_query}. # The spelling suggestion won't be used as the search query. SUGGESTION_ONLY = 1 # Automatic spell correction built by the Search API. Search will # be based on the corrected query if found. AUTO = 2 end end |