Class: Google::Cloud::DiscoveryEngine::V1::SearchResponse::Facet

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1/search_service.rb

Overview

A facet result.

Defined Under Namespace

Classes: FacetValue

Instance Attribute Summary collapse

Instance Attribute Details

#dynamic_facet::Boolean

Returns Whether the facet is dynamically generated.

Returns:

  • (::Boolean)

    Whether the facet is dynamically generated.



1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1554

class Facet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A facet value which contains value names and their count.
  # @!attribute [rw] value
  #   @return [::String]
  #     Text value of a facet, such as "Black" for facet "colors".
  #
  #     Note: The following fields are mutually exclusive: `value`, `interval`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] interval
  #   @return [::Google::Cloud::DiscoveryEngine::V1::Interval]
  #     Interval value for a facet, such as [10, 20) for facet "price". It
  #     matches
  #     {::Google::Cloud::DiscoveryEngine::V1::SearchRequest::FacetSpec::FacetKey#intervals SearchRequest.FacetSpec.FacetKey.intervals}.
  #
  #     Note: The following fields are mutually exclusive: `interval`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     Number of items that have this facet value.
  class FacetValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#key::String

Returns The key for this facet. For example, "colors" or "price". It matches SearchRequest.FacetSpec.FacetKey.key.

Returns:



1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1554

class Facet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A facet value which contains value names and their count.
  # @!attribute [rw] value
  #   @return [::String]
  #     Text value of a facet, such as "Black" for facet "colors".
  #
  #     Note: The following fields are mutually exclusive: `value`, `interval`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] interval
  #   @return [::Google::Cloud::DiscoveryEngine::V1::Interval]
  #     Interval value for a facet, such as [10, 20) for facet "price". It
  #     matches
  #     {::Google::Cloud::DiscoveryEngine::V1::SearchRequest::FacetSpec::FacetKey#intervals SearchRequest.FacetSpec.FacetKey.intervals}.
  #
  #     Note: The following fields are mutually exclusive: `interval`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     Number of items that have this facet value.
  class FacetValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#values::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::Facet::FacetValue>

Returns The facet values for this field.

Returns:



1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1554

class Facet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A facet value which contains value names and their count.
  # @!attribute [rw] value
  #   @return [::String]
  #     Text value of a facet, such as "Black" for facet "colors".
  #
  #     Note: The following fields are mutually exclusive: `value`, `interval`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] interval
  #   @return [::Google::Cloud::DiscoveryEngine::V1::Interval]
  #     Interval value for a facet, such as [10, 20) for facet "price". It
  #     matches
  #     {::Google::Cloud::DiscoveryEngine::V1::SearchRequest::FacetSpec::FacetKey#intervals SearchRequest.FacetSpec.FacetKey.intervals}.
  #
  #     Note: The following fields are mutually exclusive: `interval`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] count
  #   @return [::Integer]
  #     Number of items that have this facet value.
  class FacetValue
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end