Class: Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1/search_service.rb

Overview

Represents the search results.

Defined Under Namespace

Classes: ModelScoresEntry, RankSignals

Instance Attribute Summary collapse

Instance Attribute Details

#chunk::Google::Cloud::DiscoveryEngine::V1::Chunk

Returns The chunk data in the search response if the SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS.

Returns:



1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1483

class SearchResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A set of ranking signals.
  # @!attribute [rw] keyword_similarity_score
  #   @return [::Float]
  #     Optional. Keyword matching adjustment.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     Optional. Semantic relevance adjustment.
  # @!attribute [rw] semantic_similarity_score
  #   @return [::Float]
  #     Optional. Semantic similarity adjustment.
  # @!attribute [rw] pctr_rank
  #   @return [::Float]
  #     Optional. Predicted conversion rate adjustment as a rank.
  # @!attribute [rw] topicality_rank
  #   @return [::Float]
  #     Optional. Topicality adjustment as a rank.
  # @!attribute [rw] document_age
  #   @return [::Float]
  #     Optional. Age of the document in hours.
  # @!attribute [rw] boosting_factor
  #   @return [::Float]
  #     Optional. Combined custom boosts for a doc.
  # @!attribute [rw] default_rank
  #   @return [::Float]
  #     Optional. The default rank of the result.
  # @!attribute [rw] custom_signals
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals::CustomSignal>]
  #     Optional. A list of custom clearbox signals.
  class RankSignals
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Custom clearbox signal represented by name and value pair.
    # @!attribute [rw] name
    #   @return [::String]
    #     Optional. Name of the signal.
    # @!attribute [rw] value
    #   @return [::Float]
    #     Optional. Float value representing the ranking signal (e.g. 1.25 for
    #     BM25).
    class CustomSignal
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::DiscoveryEngine::V1::DoubleList]
  class ModelScoresEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#document::Google::Cloud::DiscoveryEngine::V1::Document

Returns The document data snippet in the search response. Only fields that are marked as retrievable are populated.

Returns:



1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1483

class SearchResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A set of ranking signals.
  # @!attribute [rw] keyword_similarity_score
  #   @return [::Float]
  #     Optional. Keyword matching adjustment.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     Optional. Semantic relevance adjustment.
  # @!attribute [rw] semantic_similarity_score
  #   @return [::Float]
  #     Optional. Semantic similarity adjustment.
  # @!attribute [rw] pctr_rank
  #   @return [::Float]
  #     Optional. Predicted conversion rate adjustment as a rank.
  # @!attribute [rw] topicality_rank
  #   @return [::Float]
  #     Optional. Topicality adjustment as a rank.
  # @!attribute [rw] document_age
  #   @return [::Float]
  #     Optional. Age of the document in hours.
  # @!attribute [rw] boosting_factor
  #   @return [::Float]
  #     Optional. Combined custom boosts for a doc.
  # @!attribute [rw] default_rank
  #   @return [::Float]
  #     Optional. The default rank of the result.
  # @!attribute [rw] custom_signals
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals::CustomSignal>]
  #     Optional. A list of custom clearbox signals.
  class RankSignals
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Custom clearbox signal represented by name and value pair.
    # @!attribute [rw] name
    #   @return [::String]
    #     Optional. Name of the signal.
    # @!attribute [rw] value
    #   @return [::Float]
    #     Optional. Float value representing the ranking signal (e.g. 1.25 for
    #     BM25).
    class CustomSignal
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::DiscoveryEngine::V1::DoubleList]
  class ModelScoresEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#id::String

Returns Document.id of the searched Document.

Returns:



1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1483

class SearchResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A set of ranking signals.
  # @!attribute [rw] keyword_similarity_score
  #   @return [::Float]
  #     Optional. Keyword matching adjustment.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     Optional. Semantic relevance adjustment.
  # @!attribute [rw] semantic_similarity_score
  #   @return [::Float]
  #     Optional. Semantic similarity adjustment.
  # @!attribute [rw] pctr_rank
  #   @return [::Float]
  #     Optional. Predicted conversion rate adjustment as a rank.
  # @!attribute [rw] topicality_rank
  #   @return [::Float]
  #     Optional. Topicality adjustment as a rank.
  # @!attribute [rw] document_age
  #   @return [::Float]
  #     Optional. Age of the document in hours.
  # @!attribute [rw] boosting_factor
  #   @return [::Float]
  #     Optional. Combined custom boosts for a doc.
  # @!attribute [rw] default_rank
  #   @return [::Float]
  #     Optional. The default rank of the result.
  # @!attribute [rw] custom_signals
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals::CustomSignal>]
  #     Optional. A list of custom clearbox signals.
  class RankSignals
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Custom clearbox signal represented by name and value pair.
    # @!attribute [rw] name
    #   @return [::String]
    #     Optional. Name of the signal.
    # @!attribute [rw] value
    #   @return [::Float]
    #     Optional. Float value representing the ranking signal (e.g. 1.25 for
    #     BM25).
    class CustomSignal
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::DiscoveryEngine::V1::DoubleList]
  class ModelScoresEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#model_scores::Google::Protobuf::Map{::String => ::Google::Cloud::DiscoveryEngine::V1::DoubleList} (readonly)

Returns Output only. Google provided available scores.

Returns:



1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1483

class SearchResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A set of ranking signals.
  # @!attribute [rw] keyword_similarity_score
  #   @return [::Float]
  #     Optional. Keyword matching adjustment.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     Optional. Semantic relevance adjustment.
  # @!attribute [rw] semantic_similarity_score
  #   @return [::Float]
  #     Optional. Semantic similarity adjustment.
  # @!attribute [rw] pctr_rank
  #   @return [::Float]
  #     Optional. Predicted conversion rate adjustment as a rank.
  # @!attribute [rw] topicality_rank
  #   @return [::Float]
  #     Optional. Topicality adjustment as a rank.
  # @!attribute [rw] document_age
  #   @return [::Float]
  #     Optional. Age of the document in hours.
  # @!attribute [rw] boosting_factor
  #   @return [::Float]
  #     Optional. Combined custom boosts for a doc.
  # @!attribute [rw] default_rank
  #   @return [::Float]
  #     Optional. The default rank of the result.
  # @!attribute [rw] custom_signals
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals::CustomSignal>]
  #     Optional. A list of custom clearbox signals.
  class RankSignals
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Custom clearbox signal represented by name and value pair.
    # @!attribute [rw] name
    #   @return [::String]
    #     Optional. Name of the signal.
    # @!attribute [rw] value
    #   @return [::Float]
    #     Optional. Float value representing the ranking signal (e.g. 1.25 for
    #     BM25).
    class CustomSignal
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::DiscoveryEngine::V1::DoubleList]
  class ModelScoresEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#rank_signals::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals

Returns Optional. A set of ranking signals associated with the result.

Returns:



1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1483

class SearchResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A set of ranking signals.
  # @!attribute [rw] keyword_similarity_score
  #   @return [::Float]
  #     Optional. Keyword matching adjustment.
  # @!attribute [rw] relevance_score
  #   @return [::Float]
  #     Optional. Semantic relevance adjustment.
  # @!attribute [rw] semantic_similarity_score
  #   @return [::Float]
  #     Optional. Semantic similarity adjustment.
  # @!attribute [rw] pctr_rank
  #   @return [::Float]
  #     Optional. Predicted conversion rate adjustment as a rank.
  # @!attribute [rw] topicality_rank
  #   @return [::Float]
  #     Optional. Topicality adjustment as a rank.
  # @!attribute [rw] document_age
  #   @return [::Float]
  #     Optional. Age of the document in hours.
  # @!attribute [rw] boosting_factor
  #   @return [::Float]
  #     Optional. Combined custom boosts for a doc.
  # @!attribute [rw] default_rank
  #   @return [::Float]
  #     Optional. The default rank of the result.
  # @!attribute [rw] custom_signals
  #   @return [::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals::CustomSignal>]
  #     Optional. A list of custom clearbox signals.
  class RankSignals
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Custom clearbox signal represented by name and value pair.
    # @!attribute [rw] name
    #   @return [::String]
    #     Optional. Name of the signal.
    # @!attribute [rw] value
    #   @return [::Float]
    #     Optional. Float value representing the ranking signal (e.g. 1.25 for
    #     BM25).
    class CustomSignal
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::DiscoveryEngine::V1::DoubleList]
  class ModelScoresEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end