Class: Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1/search_service.rb

Overview

A set of ranking signals.

Defined Under Namespace

Classes: CustomSignal

Instance Attribute Summary collapse

Instance Attribute Details

#boosting_factor::Float

Returns Optional. Combined custom boosts for a doc.

Returns:

  • (::Float)

    Optional. Combined custom boosts for a doc.



1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1476

class RankSignals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom clearbox signal represented by name and value pair.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. Name of the signal.
  # @!attribute [rw] value
  #   @return [::Float]
  #     Optional. Float value representing the ranking signal (e.g. 1.25 for
  #     BM25).
  class CustomSignal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#custom_signals::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals::CustomSignal>

Returns Optional. A list of custom clearbox signals.

Returns:



1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1476

class RankSignals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom clearbox signal represented by name and value pair.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. Name of the signal.
  # @!attribute [rw] value
  #   @return [::Float]
  #     Optional. Float value representing the ranking signal (e.g. 1.25 for
  #     BM25).
  class CustomSignal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#default_rank::Float

Returns Optional. The default rank of the result.

Returns:

  • (::Float)

    Optional. The default rank of the result.



1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1476

class RankSignals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom clearbox signal represented by name and value pair.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. Name of the signal.
  # @!attribute [rw] value
  #   @return [::Float]
  #     Optional. Float value representing the ranking signal (e.g. 1.25 for
  #     BM25).
  class CustomSignal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#document_age::Float

Returns Optional. Age of the document in hours.

Returns:

  • (::Float)

    Optional. Age of the document in hours.



1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1476

class RankSignals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom clearbox signal represented by name and value pair.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. Name of the signal.
  # @!attribute [rw] value
  #   @return [::Float]
  #     Optional. Float value representing the ranking signal (e.g. 1.25 for
  #     BM25).
  class CustomSignal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#keyword_similarity_score::Float

Returns Optional. Keyword matching adjustment.

Returns:

  • (::Float)

    Optional. Keyword matching adjustment.



1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1476

class RankSignals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom clearbox signal represented by name and value pair.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. Name of the signal.
  # @!attribute [rw] value
  #   @return [::Float]
  #     Optional. Float value representing the ranking signal (e.g. 1.25 for
  #     BM25).
  class CustomSignal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#pctr_rank::Float

Returns Optional. Predicted conversion rate adjustment as a rank.

Returns:

  • (::Float)

    Optional. Predicted conversion rate adjustment as a rank.



1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1476

class RankSignals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom clearbox signal represented by name and value pair.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. Name of the signal.
  # @!attribute [rw] value
  #   @return [::Float]
  #     Optional. Float value representing the ranking signal (e.g. 1.25 for
  #     BM25).
  class CustomSignal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#relevance_score::Float

Returns Optional. Semantic relevance adjustment.

Returns:

  • (::Float)

    Optional. Semantic relevance adjustment.



1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1476

class RankSignals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom clearbox signal represented by name and value pair.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. Name of the signal.
  # @!attribute [rw] value
  #   @return [::Float]
  #     Optional. Float value representing the ranking signal (e.g. 1.25 for
  #     BM25).
  class CustomSignal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#semantic_similarity_score::Float

Returns Optional. Semantic similarity adjustment.

Returns:

  • (::Float)

    Optional. Semantic similarity adjustment.



1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1476

class RankSignals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom clearbox signal represented by name and value pair.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. Name of the signal.
  # @!attribute [rw] value
  #   @return [::Float]
  #     Optional. Float value representing the ranking signal (e.g. 1.25 for
  #     BM25).
  class CustomSignal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#topicality_rank::Float

Returns Optional. Topicality adjustment as a rank.

Returns:

  • (::Float)

    Optional. Topicality adjustment as a rank.



1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1476

class RankSignals
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Custom clearbox signal represented by name and value pair.
  # @!attribute [rw] name
  #   @return [::String]
  #     Optional. Name of the signal.
  # @!attribute [rw] value
  #   @return [::Float]
  #     Optional. Float value representing the ranking signal (e.g. 1.25 for
  #     BM25).
  class CustomSignal
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end