Class: Google::Cloud::DiscoveryEngine::V1::GenerateGroundedContentRequest::DynamicRetrievalConfiguration
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1::GenerateGroundedContentRequest::DynamicRetrievalConfiguration
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1/grounded_generation_service.rb
Overview
Describes the options to customize dynamic retrieval.
Defined Under Namespace
Classes: DynamicRetrievalPredictor
Instance Attribute Summary collapse
-
#predictor ⇒ ::Google::Cloud::DiscoveryEngine::V1::GenerateGroundedContentRequest::DynamicRetrievalConfiguration::DynamicRetrievalPredictor
Specification for the predictor for dynamic retrieval.
Instance Attribute Details
#predictor ⇒ ::Google::Cloud::DiscoveryEngine::V1::GenerateGroundedContentRequest::DynamicRetrievalConfiguration::DynamicRetrievalPredictor
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'proto_docs/google/cloud/discoveryengine/v1/grounded_generation_service.rb', line 135 class DynamicRetrievalConfiguration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes the predictor settings for dynamic retrieval. # @!attribute [rw] version # @return [::Google::Cloud::DiscoveryEngine::V1::GenerateGroundedContentRequest::DynamicRetrievalConfiguration::DynamicRetrievalPredictor::Version] # The version of the predictor to be used in dynamic retrieval. # @!attribute [rw] threshold # @return [::Float] # The value of the threshold. If the predictor will predict a # value smaller than this, it would suppress grounding in the source. class DynamicRetrievalPredictor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The version of the predictor to be used in dynamic retrieval. module Version # Automatically choose the best version of the retrieval predictor. VERSION_UNSPECIFIED = 0 # The V1 model which is evaluating each source independently. V1_INDEPENDENT = 1 end end end |