Class: Google::Cloud::DiscoveryEngine::V1::SearchRequest::QueryExpansionSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/discoveryengine/v1/search_service.rb

Overview

Specification to determine under which conditions query expansion should occur.

Defined Under Namespace

Modules: Condition

Instance Attribute Summary collapse

Instance Attribute Details

#condition::Google::Cloud::DiscoveryEngine::V1::SearchRequest::QueryExpansionSpec::Condition

Returns The condition under which query expansion should occur. Default to Condition.DISABLED.

Returns:



754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 754

class QueryExpansionSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum describing under which condition query expansion should occur.
  module Condition
    # Unspecified query expansion condition. In this case, server behavior
    # defaults to
    # {::Google::Cloud::DiscoveryEngine::V1::SearchRequest::QueryExpansionSpec::Condition::DISABLED Condition.DISABLED}.
    CONDITION_UNSPECIFIED = 0

    # Disabled query expansion. Only the exact search query is used, even if
    # {::Google::Cloud::DiscoveryEngine::V1::SearchResponse#total_size SearchResponse.total_size}
    # is zero.
    DISABLED = 1

    # Automatic query expansion built by the Search API.
    AUTO = 2
  end
end

#pin_unexpanded_results::Boolean

Returns Whether to pin unexpanded results. If this field is set to true, unexpanded products are always at the top of the search results, followed by the expanded results.

Returns:

  • (::Boolean)

    Whether to pin unexpanded results. If this field is set to true, unexpanded products are always at the top of the search results, followed by the expanded results.



754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 754

class QueryExpansionSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum describing under which condition query expansion should occur.
  module Condition
    # Unspecified query expansion condition. In this case, server behavior
    # defaults to
    # {::Google::Cloud::DiscoveryEngine::V1::SearchRequest::QueryExpansionSpec::Condition::DISABLED Condition.DISABLED}.
    CONDITION_UNSPECIFIED = 0

    # Disabled query expansion. Only the exact search query is used, even if
    # {::Google::Cloud::DiscoveryEngine::V1::SearchResponse#total_size SearchResponse.total_size}
    # is zero.
    DISABLED = 1

    # Automatic query expansion built by the Search API.
    AUTO = 2
  end
end