Module: Google::Cloud::DiscoveryEngine::V1::SearchRequest::RankingExpressionBackend
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1/search_service.rb
Overview
The backend to use for the ranking expression evaluation.
Constant Summary collapse
- RANKING_EXPRESSION_BACKEND_UNSPECIFIED =
Default option for unspecified/unknown values.
0- BYOE =
Deprecated: Use
RANK_BY_EMBEDDINGinstead. Ranking by custom embedding model, the default way to evaluate the ranking expression. Legacy enum option,RANK_BY_EMBEDDINGshould be used instead. 1- CLEARBOX =
Deprecated: Use
RANK_BY_FORMULAinstead. Ranking by custom formula. Legacy enum option,RANK_BY_FORMULAshould be used instead. 2- RANK_BY_EMBEDDING =
Ranking by custom embedding model, the default way to evaluate the ranking expression.
3- RANK_BY_FORMULA =
Ranking by custom formula.
4