Class: Google::Cloud::DiscoveryEngine::V1::SearchResponse::Facet
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1::SearchResponse::Facet
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1/search_service.rb
Overview
A facet result.
Defined Under Namespace
Classes: FacetValue
Instance Attribute Summary collapse
-
#dynamic_facet ⇒ ::Boolean
Whether the facet is dynamically generated.
-
#key ⇒ ::String
The key for this facet.
-
#values ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::Facet::FacetValue>
The facet values for this field.
Instance Attribute Details
#dynamic_facet ⇒ ::Boolean
Returns Whether the facet is dynamically generated.
1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 |
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1515 class Facet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A facet value which contains value names and their count. # @!attribute [rw] value # @return [::String] # Text value of a facet, such as "Black" for facet "colors". # # Note: The following fields are mutually exclusive: `value`, `interval`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] interval # @return [::Google::Cloud::DiscoveryEngine::V1::Interval] # Interval value for a facet, such as [10, 20) for facet "price". It # matches # {::Google::Cloud::DiscoveryEngine::V1::SearchRequest::FacetSpec::FacetKey#intervals SearchRequest.FacetSpec.FacetKey.intervals}. # # Note: The following fields are mutually exclusive: `interval`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] count # @return [::Integer] # Number of items that have this facet value. class FacetValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#key ⇒ ::String
Returns The key for this facet. For example, "colors" or "price". It matches
SearchRequest.FacetSpec.FacetKey.key.
1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 |
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1515 class Facet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A facet value which contains value names and their count. # @!attribute [rw] value # @return [::String] # Text value of a facet, such as "Black" for facet "colors". # # Note: The following fields are mutually exclusive: `value`, `interval`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] interval # @return [::Google::Cloud::DiscoveryEngine::V1::Interval] # Interval value for a facet, such as [10, 20) for facet "price". It # matches # {::Google::Cloud::DiscoveryEngine::V1::SearchRequest::FacetSpec::FacetKey#intervals SearchRequest.FacetSpec.FacetKey.intervals}. # # Note: The following fields are mutually exclusive: `interval`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] count # @return [::Integer] # Number of items that have this facet value. class FacetValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#values ⇒ ::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::Facet::FacetValue>
Returns The facet values for this field.
1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 |
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1515 class Facet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A facet value which contains value names and their count. # @!attribute [rw] value # @return [::String] # Text value of a facet, such as "Black" for facet "colors". # # Note: The following fields are mutually exclusive: `value`, `interval`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] interval # @return [::Google::Cloud::DiscoveryEngine::V1::Interval] # Interval value for a facet, such as [10, 20) for facet "price". It # matches # {::Google::Cloud::DiscoveryEngine::V1::SearchRequest::FacetSpec::FacetKey#intervals SearchRequest.FacetSpec.FacetKey.intervals}. # # Note: The following fields are mutually exclusive: `interval`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] count # @return [::Integer] # Number of items that have this facet value. class FacetValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |