Class: Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1/search_service.rb
Overview
Represents the search results.
Defined Under Namespace
Classes: ModelScoresEntry, RankSignals
Instance Attribute Summary collapse
-
#chunk ⇒ ::Google::Cloud::DiscoveryEngine::V1::Chunk
The chunk data in the search response if the SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS.
-
#document ⇒ ::Google::Cloud::DiscoveryEngine::V1::Document
The document data snippet in the search response.
-
#id ⇒ ::String
Document.id of the searched Document.
-
#model_scores ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::DiscoveryEngine::V1::DoubleList}
readonly
Output only.
-
#rank_signals ⇒ ::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals
Optional.
Instance Attribute Details
#chunk ⇒ ::Google::Cloud::DiscoveryEngine::V1::Chunk
Returns The chunk data in the search response if the SearchRequest.ContentSearchSpec.search_result_mode is set to CHUNKS.
1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1444 class SearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A set of ranking signals. # @!attribute [rw] keyword_similarity_score # @return [::Float] # Optional. Keyword matching adjustment. # @!attribute [rw] relevance_score # @return [::Float] # Optional. Semantic relevance adjustment. # @!attribute [rw] semantic_similarity_score # @return [::Float] # Optional. Semantic similarity adjustment. # @!attribute [rw] pctr_rank # @return [::Float] # Optional. Predicted conversion rate adjustment as a rank. # @!attribute [rw] topicality_rank # @return [::Float] # Optional. Topicality adjustment as a rank. # @!attribute [rw] document_age # @return [::Float] # Optional. Age of the document in hours. # @!attribute [rw] boosting_factor # @return [::Float] # Optional. Combined custom boosts for a doc. # @!attribute [rw] default_rank # @return [::Float] # Optional. The default rank of the result. # @!attribute [rw] custom_signals # @return [::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals::CustomSignal>] # Optional. A list of custom clearbox signals. class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::DiscoveryEngine::V1::DoubleList] class ModelScoresEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#document ⇒ ::Google::Cloud::DiscoveryEngine::V1::Document
Returns The document data snippet in the search response. Only fields that are
marked as retrievable are populated.
1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1444 class SearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A set of ranking signals. # @!attribute [rw] keyword_similarity_score # @return [::Float] # Optional. Keyword matching adjustment. # @!attribute [rw] relevance_score # @return [::Float] # Optional. Semantic relevance adjustment. # @!attribute [rw] semantic_similarity_score # @return [::Float] # Optional. Semantic similarity adjustment. # @!attribute [rw] pctr_rank # @return [::Float] # Optional. Predicted conversion rate adjustment as a rank. # @!attribute [rw] topicality_rank # @return [::Float] # Optional. Topicality adjustment as a rank. # @!attribute [rw] document_age # @return [::Float] # Optional. Age of the document in hours. # @!attribute [rw] boosting_factor # @return [::Float] # Optional. Combined custom boosts for a doc. # @!attribute [rw] default_rank # @return [::Float] # Optional. The default rank of the result. # @!attribute [rw] custom_signals # @return [::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals::CustomSignal>] # Optional. A list of custom clearbox signals. class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::DiscoveryEngine::V1::DoubleList] class ModelScoresEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#id ⇒ ::String
Returns Document.id of the searched Document.
1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1444 class SearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A set of ranking signals. # @!attribute [rw] keyword_similarity_score # @return [::Float] # Optional. Keyword matching adjustment. # @!attribute [rw] relevance_score # @return [::Float] # Optional. Semantic relevance adjustment. # @!attribute [rw] semantic_similarity_score # @return [::Float] # Optional. Semantic similarity adjustment. # @!attribute [rw] pctr_rank # @return [::Float] # Optional. Predicted conversion rate adjustment as a rank. # @!attribute [rw] topicality_rank # @return [::Float] # Optional. Topicality adjustment as a rank. # @!attribute [rw] document_age # @return [::Float] # Optional. Age of the document in hours. # @!attribute [rw] boosting_factor # @return [::Float] # Optional. Combined custom boosts for a doc. # @!attribute [rw] default_rank # @return [::Float] # Optional. The default rank of the result. # @!attribute [rw] custom_signals # @return [::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals::CustomSignal>] # Optional. A list of custom clearbox signals. class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::DiscoveryEngine::V1::DoubleList] class ModelScoresEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#model_scores ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::DiscoveryEngine::V1::DoubleList} (readonly)
Returns Output only. Google provided available scores.
1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1444 class SearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A set of ranking signals. # @!attribute [rw] keyword_similarity_score # @return [::Float] # Optional. Keyword matching adjustment. # @!attribute [rw] relevance_score # @return [::Float] # Optional. Semantic relevance adjustment. # @!attribute [rw] semantic_similarity_score # @return [::Float] # Optional. Semantic similarity adjustment. # @!attribute [rw] pctr_rank # @return [::Float] # Optional. Predicted conversion rate adjustment as a rank. # @!attribute [rw] topicality_rank # @return [::Float] # Optional. Topicality adjustment as a rank. # @!attribute [rw] document_age # @return [::Float] # Optional. Age of the document in hours. # @!attribute [rw] boosting_factor # @return [::Float] # Optional. Combined custom boosts for a doc. # @!attribute [rw] default_rank # @return [::Float] # Optional. The default rank of the result. # @!attribute [rw] custom_signals # @return [::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals::CustomSignal>] # Optional. A list of custom clearbox signals. class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::DiscoveryEngine::V1::DoubleList] class ModelScoresEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#rank_signals ⇒ ::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals
Returns Optional. A set of ranking signals associated with the result.
1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 |
# File 'proto_docs/google/cloud/discoveryengine/v1/search_service.rb', line 1444 class SearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A set of ranking signals. # @!attribute [rw] keyword_similarity_score # @return [::Float] # Optional. Keyword matching adjustment. # @!attribute [rw] relevance_score # @return [::Float] # Optional. Semantic relevance adjustment. # @!attribute [rw] semantic_similarity_score # @return [::Float] # Optional. Semantic similarity adjustment. # @!attribute [rw] pctr_rank # @return [::Float] # Optional. Predicted conversion rate adjustment as a rank. # @!attribute [rw] topicality_rank # @return [::Float] # Optional. Topicality adjustment as a rank. # @!attribute [rw] document_age # @return [::Float] # Optional. Age of the document in hours. # @!attribute [rw] boosting_factor # @return [::Float] # Optional. Combined custom boosts for a doc. # @!attribute [rw] default_rank # @return [::Float] # Optional. The default rank of the result. # @!attribute [rw] custom_signals # @return [::Array<::Google::Cloud::DiscoveryEngine::V1::SearchResponse::SearchResult::RankSignals::CustomSignal>] # Optional. A list of custom clearbox signals. class RankSignals include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Custom clearbox signal represented by name and value pair. # @!attribute [rw] name # @return [::String] # Optional. Name of the signal. # @!attribute [rw] value # @return [::Float] # Optional. Float value representing the ranking signal (e.g. 1.25 for # BM25). class CustomSignal include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::DiscoveryEngine::V1::DoubleList] class ModelScoresEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |