Class: Google::Cloud::DiscoveryEngine::V1::WorkspaceConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DiscoveryEngine::V1::WorkspaceConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/discoveryengine/v1/data_store.rb
Overview
Config to store data store type configuration for workspace data
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#dasher_customer_id ⇒ ::String
Obfuscated Dasher customer ID.
-
#super_admin_email_address ⇒ ::String
Optional.
-
#super_admin_service_account ⇒ ::String
Optional.
-
#type ⇒ ::Google::Cloud::DiscoveryEngine::V1::WorkspaceConfig::Type
The Google Workspace data source.
Instance Attribute Details
#dasher_customer_id ⇒ ::String
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'proto_docs/google/cloud/discoveryengine/v1/data_store.rb', line 251 class WorkspaceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of Workspace App supported by this DataStore module Type # Defaults to an unspecified Workspace type. TYPE_UNSPECIFIED = 0 # Workspace Data Store contains Drive data GOOGLE_DRIVE = 1 # Workspace Data Store contains Mail data GOOGLE_MAIL = 2 # Workspace Data Store contains Sites data GOOGLE_SITES = 3 # Workspace Data Store contains Calendar data GOOGLE_CALENDAR = 4 # Workspace Data Store contains Chat data GOOGLE_CHAT = 5 # Workspace Data Store contains Groups data GOOGLE_GROUPS = 6 # Workspace Data Store contains Keep data GOOGLE_KEEP = 7 # Workspace Data Store contains People data GOOGLE_PEOPLE = 8 end end |
#super_admin_email_address ⇒ ::String
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'proto_docs/google/cloud/discoveryengine/v1/data_store.rb', line 251 class WorkspaceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of Workspace App supported by this DataStore module Type # Defaults to an unspecified Workspace type. TYPE_UNSPECIFIED = 0 # Workspace Data Store contains Drive data GOOGLE_DRIVE = 1 # Workspace Data Store contains Mail data GOOGLE_MAIL = 2 # Workspace Data Store contains Sites data GOOGLE_SITES = 3 # Workspace Data Store contains Calendar data GOOGLE_CALENDAR = 4 # Workspace Data Store contains Chat data GOOGLE_CHAT = 5 # Workspace Data Store contains Groups data GOOGLE_GROUPS = 6 # Workspace Data Store contains Keep data GOOGLE_KEEP = 7 # Workspace Data Store contains People data GOOGLE_PEOPLE = 8 end end |
#super_admin_service_account ⇒ ::String
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'proto_docs/google/cloud/discoveryengine/v1/data_store.rb', line 251 class WorkspaceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of Workspace App supported by this DataStore module Type # Defaults to an unspecified Workspace type. TYPE_UNSPECIFIED = 0 # Workspace Data Store contains Drive data GOOGLE_DRIVE = 1 # Workspace Data Store contains Mail data GOOGLE_MAIL = 2 # Workspace Data Store contains Sites data GOOGLE_SITES = 3 # Workspace Data Store contains Calendar data GOOGLE_CALENDAR = 4 # Workspace Data Store contains Chat data GOOGLE_CHAT = 5 # Workspace Data Store contains Groups data GOOGLE_GROUPS = 6 # Workspace Data Store contains Keep data GOOGLE_KEEP = 7 # Workspace Data Store contains People data GOOGLE_PEOPLE = 8 end end |
#type ⇒ ::Google::Cloud::DiscoveryEngine::V1::WorkspaceConfig::Type
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'proto_docs/google/cloud/discoveryengine/v1/data_store.rb', line 251 class WorkspaceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies the type of Workspace App supported by this DataStore module Type # Defaults to an unspecified Workspace type. TYPE_UNSPECIFIED = 0 # Workspace Data Store contains Drive data GOOGLE_DRIVE = 1 # Workspace Data Store contains Mail data GOOGLE_MAIL = 2 # Workspace Data Store contains Sites data GOOGLE_SITES = 3 # Workspace Data Store contains Calendar data GOOGLE_CALENDAR = 4 # Workspace Data Store contains Chat data GOOGLE_CHAT = 5 # Workspace Data Store contains Groups data GOOGLE_GROUPS = 6 # Workspace Data Store contains Keep data GOOGLE_KEEP = 7 # Workspace Data Store contains People data GOOGLE_PEOPLE = 8 end end |